@@ -5,7 +5,9 @@ from typing import Optional
 import pytz
 
 DISCORD_DEFAULT_TZ = pytz.timezone('US/Pacific')
-
+JP_TIMEZONE = pytz.timezone('Japan')
+NA_TIMEZONE = timezone(timedelta(hours=-8))
+KR_TIMEZONE = pytz.timezone('Asia/Seoul')
 
 def tzstr_to_timezone(self, tzstr: str) -> Optional[tzinfo]:
     tzstr = tzstr.upper().strip()
@@ -18,11 +20,12 @@ def tzstr_to_timezone(self, tzstr: str) -> Optional[tzinfo]:
     if tzstr in ('CST', 'CDT', 'CT'):
         return pytz.timezone('America/Chicago')
     if tzstr in ('JP', 'JST', 'JT'):
-        return pytz.timezone('Japan')
+        return JP_TIMEZONE
     if tzstr in ('NA', 'US'):
-        return timezone(timedelta(hours=-9))
+        return NA_TIMEZONE
     if tzstr in ('KR',):
-        return pytz.timezone('Asia/Seoul')
+        return KR_TIMEZONE
+
     tz_lookup = dict([(pytz.timezone(x).localize(datetime.now()).tzname(), pytz.timezone(x))
                       for x in pytz.all_timezones])
     if tzstr in tz_lookup:
